#!/bin/bash

VERS="`grep '^# *define *.*VERSION ' version.h src/version.h *.h src/*.h 2>/dev/null | head -1 | sed -e s/'^.* '//g -e s/'"'//g`"
if [ ! -f makearch.info ]; then
	echo "Error: No \"makearch.info\" file found." >&2
	exit 1
fi
DATE_VAL="`date`"

source makearch.info

if [ -z "${UTIL}" ]; then
	echo "Error: Unable to determine utility name, aborting." >&2
	exit 1
fi
if [ -z "${VERS}" ]; then
	echo "Error: Unable to determine version number, aborting." >&2
	exit 1
fi
if echo ${UTIL} | egrep '(/|-)'  2>/dev/null >/dev/null; then
	echo "Error: Utility name has a dash (-) or slash (/) in it." >&2
	exit 1
fi

mkdir ../${UTIL}-${VERS} || exit 1
cp -a * ../${UTIL}-${VERS} 2>/dev/null >/dev/null
cd ../${UTIL}-${VERS} || exit 1
rm -f makearch.info .* 2>/dev/null >/dev/null
find . -name 'CVS' -type d -exec rm {} \; >/dev/null 2>/dev/null


make clean 2>/dev/null >/dev/null
make distclean 2>/dev/null >/dev/null
./configure 2>/dev/null >/dev/null
make 2>/dev/null >/dev/null
for file in ${BINS}; do
	if [ ! -x ${file} ]; then
		echo "Sanity check: building \"${file}\" failed." >&2
		exit=true
	fi
done
for file in ${REQS}; do
	if [ ! -f ${file} ]; then
		echo "Sanity check: required file \"${file}\" failed." >&2
		exit=true
	fi
done
for file in ${DOC_HDR} ${DOCS}; do
	if [ -f "${file}" ]; then
		TMPFILE="/tmp/sed$$`date +%H%M%S`${RANDOM}"
		rm -f ${TMPFILE} 2>/dev/null >/dev/null
		sed -e s/'@@VERS@@'/"${VERS}"/g -e s/'@@UTIL@@'/"${UTIL}"/g -e s/'@@DATE@@'/"${DATE_VAL}"/g ${file} > ${TMPFILE}
		if [ ! "${file}" = "${DOC_HDR}" -a -f "${DOC_HDR}" ]; then
			cat ${DOC_HDR} > ${file}
		else
			echo -n > ${file}
		fi
		cat ${TMPFILE} >> ${file}
		rm -f ${TMPFILE} 2>/dev/null >/dev/null
	fi
done
for file in ${TMPS}; do
	if echo ${file} | grep '/' 2>/dev/null >/dev/null; then
		echo "Error: TMPS list contains a slash (/)" >&2
		exit=true
		break
	fi
	if [ -d "${file}" ]; then
		rm -rf "${file}" 2>/dev/null >/dev/null
	else
		rm -f ${file} 2>/dev/null >/dev/null
	fi
done
if [ ! -z "${AFTER}" -a -x "${AFTER}" ]; then
	${AFTER}
fi
if [ ! -z "${exit}" ]; then
	cd ../
	rm -rf ${UTIL}-${VERS}/ 2>/dev/null >/dev/null
	exit 1
fi


make clean 2>/dev/null >/dev/null
make distclean 2>/dev/null >/dev/null
make depend 2>/dev/null >/dev/null
rm -f MD5SUMS 2>/dev/null >/dev/null
find . -type f -print 2>/dev/null | sed s/'^\.\/'/''/ | xargs md5sum >> MD5SUMS 2>/dev/null

cd ../
echo "Creating ${UTIL}-${VERS}.tar.gz..."
tar -zcvf ${UTIL}-${VERS}.tar.gz ${UTIL}-${VERS}/
rm -rf ${UTIL}-${VERS}/ 2>/dev/null >/dev/null
if [ -d archive ]; then
	mkdir -p archive/${UTIL}/ 2>/dev/null
	mv ${UTIL}-${VERS}.tar.gz archive/${UTIL}/ 2>/dev/null >/dev/null
	for file in archive/${UTIL}-*.tar.gz; do
		if [ -L "${file}" ]; then rm -f ${file} 2>/dev/null; fi
	done
	ln -s ${UTIL}/${UTIL}-${VERS}.tar.gz archive/${UTIL}-${VERS}.tar.gz 2>/dev/null >/dev/null
fi
